@@ -1,7 +1,7 @@
 use crate::pda::PDA;
 
 use anchor_lang::prelude::*;
-use anchor_lang::AccountDeserialize;
+
 use std::convert::TryFrom;
 
 pub const SEED_AUTHORITY: &[u8] = b"authority";
@@ -23,8 +23,8 @@ impl Authority {
 }
 
 impl TryFrom<Vec<u8>> for Authority {
-    type Error = ProgramError;
-    fn try_from(data: Vec<u8>) -> Result<Self, Self::Error> {
+    type Error = Error;
+    fn try_from(data: Vec<u8>) -> std::result::Result<Self, Self::Error> {
         Authority::try_deserialize(&mut data.as_slice())
     }
 }
@@ -34,11 +34,11 @@ impl TryFrom<Vec<u8>> for Authority {
  */
 
 pub trait AuthorityAccount {
-    fn init(&mut self, bump: u8) -> ProgramResult;
+    fn init(&mut self, bump: u8) -> Result<()>;
 }
 
 impl AuthorityAccount for Account<'_, Authority> {
-    fn init(&mut self, bump: u8) -> ProgramResult {
+    fn init(&mut self, bump: u8) -> Result<()> {
         self.bump = bump;
         Ok(())
     }
